@@ -16,6 +16,7 @@ package org.eclipse.debug.internal.core;
 
 
 import java.io.IOException;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -44,8 +45,6 @@ import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 import org.w3c.dom.NodeList;
 
-import com.ibm.icu.text.MessageFormat;
-
 /**
  * The information associated with a launch configuration handle.
  */
@@ -123,7 +122,7 @@ public class LaunchConfigurationInfo {
 	 * Constructs a new empty info
 	 */
 	protected LaunchConfigurationInfo() {
-		setAttributeTable(new TreeMap<String, Object>());
+		setAttributeTable(new TreeMap<>());
 	}
 
 	/**
@@ -152,10 +151,10 @@ public class LaunchConfigurationInfo {
 	 */
 	protected void setAttributes(Map<String, ?> map) {
 		if (map == null) {
-			setAttributeTable(new TreeMap<String, Object>());
+			setAttributeTable(new TreeMap<>());
 			return;
 		}
-		setAttributeTable(new TreeMap<String, Object>(map));
+		setAttributeTable(new TreeMap<>(map));
 	}
 
 	/**
@@ -897,7 +896,7 @@ public class LaunchConfigurationInfo {
 			String strAttr1 = null;
 			String strAttr2 = null;
 			if (fgIsSun14x) {
-				if(attr2 instanceof String & attr1 instanceof String) {
+				if(attr2 instanceof String && attr1 instanceof String) {
 					// this is a hack for bug 110215, on SUN 1.4.x, \r
 					// is stripped off when the stream is written to the
 					// DOM
