@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2019 Paul Pazderski and others.
+ * Copyright (c) 2019, 2020 Paul Pazderski and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -13,10 +13,18 @@
  *******************************************************************************/
 package org.eclipse.debug.tests.console;
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNotSame;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.IOException;
 import java.util.Arrays;
 import java.util.List;
 
+import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.debug.tests.TestUtil;
 import org.eclipse.jface.text.BadLocationException;
@@ -24,16 +32,16 @@ import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.IDocumentPartitioner;
 import org.eclipse.jface.text.IRegion;
 import org.eclipse.jface.text.ITypedRegion;
+import org.eclipse.jface.text.Region;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.custom.ST;
 import org.eclipse.swt.custom.StyledText;
+import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.ui.console.IConsoleDocumentPartitioner;
 import org.eclipse.ui.console.IOConsole;
 import org.eclipse.ui.console.IOConsoleOutputStream;
 
-import junit.framework.TestCase;
-
 /**
  * Utility to help testing input and output in {@link IOConsole}.
  */
@@ -55,6 +63,24 @@ public final class IOConsoleTestUtil {
 	 * initialized.
 	 */
 	private IOConsoleOutputStream defaultOut = null;
+	/**
+	 * This utility was initial written to be used with disabled fixed width
+	 * console. If fixed width is enabled some methods like 'set caret to line
+	 * end' may behave unexpected if a test case was written with non fixed
+	 * width console in mind.
+	 * <p>
+	 * If this field is set to <code>true</code> all methods which may behave
+	 * problematic in fixed width are executed in a way so that there result is
+	 * the same as if the console has no fixed width enabled. E.g. 'set caret to
+	 * line end' ignores virtual line wraps and jumps to the next real line
+	 * delimiter.
+	 * </p>
+	 * <p>
+	 * If this field is set to <code>true</code> any test written for non fixed
+	 * width mode should succeed regardless of the fixed width setting.
+	 * </p>
+	 */
+	private boolean ignoreFixedConsole = false;
 
 	/**
 	 * Create a new testing helper.
@@ -68,11 +94,11 @@ public final class IOConsoleTestUtil {
 	 */
 	public IOConsoleTestUtil(IOConsole console, StyledText textPanel, String name) {
 		this.console = console;
-		TestCase.assertNotNull(this.console);
+		assertNotNull(this.console);
 		this.doc = console.getDocument();
-		TestCase.assertNotNull(this.doc);
+		assertNotNull(this.doc);
 		final Class<?> expectedInterface = IConsoleDocumentPartitioner.class;
-		TestCase.assertTrue("Expected partitioner implements " + expectedInterface.getName() + //
+		assertTrue("Expected partitioner implements " + expectedInterface.getName() + //
 				". Found: " + this.doc.getDocumentPartitioner().getClass(), //
 				expectedInterface.isAssignableFrom(this.doc.getDocumentPartitioner().getClass()));
 		this.partitioner = (IConsoleDocumentPartitioner) this.doc.getDocumentPartitioner();
@@ -88,8 +114,8 @@ public final class IOConsoleTestUtil {
 	 */
 	public IOConsoleTestUtil clear() throws Exception {
 		console.clearConsole();
-		waitForScheduledJobs();
-		TestCase.assertEquals("Console is not cleared.", 0, doc.getLength());
+		flush();
+		assertEquals("Console is not cleared.", 0, doc.getLength());
 		return this;
 	}
 
@@ -100,7 +126,9 @@ public final class IOConsoleTestUtil {
 	 * @param s content to write in output stream
 	 * @return this {@link IOConsoleTestUtil} to chain methods
 	 * @see #write(String)
+	 * @see #flush()
 	 */
+	@SuppressWarnings("resource")
 	public IOConsoleTestUtil writeFast(final String s) throws IOException {
 		return writeFast(s, getDefaultOutputStream());
 	}
@@ -113,6 +141,7 @@ public final class IOConsoleTestUtil {
 	 * @return this {@link IOConsoleTestUtil} to chain methods
 	 * @see #writeFast(String)
 	 */
+	@SuppressWarnings("resource")
 	public IOConsoleTestUtil write(final String s) throws Exception {
 		return write(s, getDefaultOutputStream());
 	}
@@ -128,6 +157,7 @@ public final class IOConsoleTestUtil {
 	 * @param s content to write in output stream
 	 * @return this {@link IOConsoleTestUtil} to chain methods
 	 */
+	@SuppressWarnings("resource")
 	public IOConsoleTestUtil writeAndVerify(final String s) throws Exception {
 		return writeAndVerify(s, getDefaultOutputStream());
 	}
@@ -140,6 +170,7 @@ public final class IOConsoleTestUtil {
 	 * @param out use this output stream instead of default one
 	 * @return this {@link IOConsoleTestUtil} to chain methods
 	 * @see #write(String, IOConsoleOutputStream)
+	 * @see #flush()
 	 */
 	public IOConsoleTestUtil writeFast(final String s, IOConsoleOutputStream out) throws IOException {
 		out.write(s);
@@ -157,7 +188,7 @@ public final class IOConsoleTestUtil {
 	 */
 	public IOConsoleTestUtil write(final String s, IOConsoleOutputStream out) throws Exception {
 		writeFast(s, out);
-		waitForScheduledJobs();
+		flush();
 		return this;
 	}
 
@@ -176,7 +207,7 @@ public final class IOConsoleTestUtil {
 	public IOConsoleTestUtil writeAndVerify(final String s, IOConsoleOutputStream out) throws Exception {
 		final int oldLength = doc.getLength();
 		write(s, out);
-		TestCase.assertEquals("Console content length not as expected.", oldLength + s.length(), doc.getLength());
+		assertEquals("Console content length not as expected.", oldLength + s.length(), doc.getLength());
 		verifyContentByOffset(s, oldLength);
 		verifyOutputPartitions(oldLength, s.length());
 		return this;
@@ -230,8 +261,8 @@ public final class IOConsoleTestUtil {
 		final int oldSelectionLength = textPanel.getSelectionCount();
 		final int oldOffset = getCaretOffset() - oldSelectionLength;
 		insert(content);
-		TestCase.assertEquals("Console content length not as expected.", oldLength + content.length() - oldSelectionLength, doc.getLength());
-		TestCase.assertEquals("Caret not at expected position.", oldOffset + content.length(), getCaretOffset());
+		assertEquals("Console content length not as expected.", oldLength + content.length() - oldSelectionLength, doc.getLength());
+		assertEquals("Caret not at expected position.", oldOffset + content.length(), getCaretOffset());
 		verifyContentByOffset(content, oldOffset);
 		verifyInputPartitions(oldOffset, content.length());
 		return this;
@@ -280,8 +311,8 @@ public final class IOConsoleTestUtil {
 		final int oldSelectionLength = textPanel.getSelectionCount();
 		final int oldOffset = getCaretOffset() - oldSelectionLength;
 		insertTyping(content);
-		TestCase.assertEquals("Console content length not as expected.", oldLength + content.length() - oldSelectionLength, doc.getLength());
-		TestCase.assertEquals("Caret not at expected position.", oldOffset + content.length(), getCaretOffset());
+		assertEquals("Console content length not as expected.", oldLength + content.length() - oldSelectionLength, doc.getLength());
+		assertEquals("Caret not at expected position.", oldOffset + content.length(), getCaretOffset());
 		verifyContentByOffset(content, oldOffset);
 		verifyInputPartitions(oldOffset, content.length());
 		return this;
@@ -304,7 +335,34 @@ public final class IOConsoleTestUtil {
 	 */
 	public IOConsoleTestUtil backspace(int repeat) {
 		for (int i = 0; i < repeat; i++) {
-			textPanel.invokeAction(ST.DELETE_PREVIOUS);
+			if (ignoreFixedConsole) {
+				// Note: this backspace simulation can not handle multibyte line
+				// delimiter. It would only delete one byte with one backspace.
+				final Event e = new Event();
+				e.doit = true;
+				e.text = "";
+				final IRegion selection = getSelection();
+				if (selection.getLength() == 0) {
+					final int caretOffset = getCaretOffset();
+					e.start = caretOffset - 1;
+					e.end = caretOffset;
+					if (caretOffset <= 0) {
+						e.doit = false;
+					}
+				} else {
+					e.start = selection.getOffset();
+					e.end = selection.getOffset() + selection.getLength();
+				}
+				if (e.doit) {
+					textPanel.notifyListeners(SWT.Verify, e);
+				}
+				if (e.doit) {
+					textPanel.replaceTextRange(e.start, e.end - e.start, e.text);
+					setCaretOffset(e.start);
+				}
+			} else {
+				textPanel.invokeAction(ST.DELETE_PREVIOUS);
+			}
 		}
 		return this;
 	}
@@ -316,7 +374,7 @@ public final class IOConsoleTestUtil {
 	 */
 	public IOConsoleTestUtil enter() {
 		// Note: newline will be replaced by
-		// System.getProperty("line.separator") so do not assume document length
+		// System.lineSeparator() so do not assume document length
 		// will increase by 1
 		insertTyping("\n");
 		return this;
@@ -344,6 +402,17 @@ public final class IOConsoleTestUtil {
 		return this;
 	}
 
+	/**
+	 * Set caret to offset relative to start of current line.
+	 *
+	 * @param offset relative offset to line start
+	 * @return this {@link IOConsoleTestUtil} to chain methods
+	 */
+	public IOConsoleTestUtil setCaretLineRelative(int offset) {
+		moveCaretToLineStart().moveCaret(offset);
+		return this;
+	}
+
 	/**
 	 * Move caret by given amount forth or back.
 	 *
@@ -382,7 +451,17 @@ public final class IOConsoleTestUtil {
 	 * @return this {@link IOConsoleTestUtil} to chain methods
 	 */
 	public IOConsoleTestUtil moveCaretToLineStart() {
-		textPanel.invokeAction(ST.LINE_START);
+		if (ignoreFixedConsole) {
+			try {
+				final int currentOffset = getCaretOffset();
+				final int docLineStart = getDocument().getLineInformationOfOffset(currentOffset).getOffset();
+				setCaretOffset(docLineStart);
+			} catch (BadLocationException e) {
+				TestUtil.log(IStatus.ERROR, name, "Failed to set caret to line start in wrapped line mode.", e);
+			}
+		} else {
+			textPanel.invokeAction(ST.LINE_START);
+		}
 		return this;
 	}
 
@@ -392,10 +471,30 @@ public final class IOConsoleTestUtil {
 	 * @return this {@link IOConsoleTestUtil} to chain methods
 	 */
 	public IOConsoleTestUtil moveCaretToLineEnd() {
-		textPanel.invokeAction(ST.LINE_END);
+		if (ignoreFixedConsole) {
+			try {
+				final int currentOffset = getCaretOffset();
+				final IRegion docLine = getDocument().getLineInformationOfOffset(currentOffset);
+				setCaretOffset(docLine.getOffset() + docLine.getLength());
+			} catch (BadLocationException e) {
+				TestUtil.log(IStatus.ERROR, name, "Failed to set caret to line end in wrapped line mode.", e);
+			}
+		} else {
+			textPanel.invokeAction(ST.LINE_END);
+		}
 		return this;
 	}
 
+	/**
+	 * Get the selected text region in console.
+	 *
+	 * @return the selected region
+	 */
+	public IRegion getSelection() {
+		final Point selection = textPanel.getSelection();
+		return new Region(selection.x, selection.y - selection.x);
+	}
+
 	/**
 	 * Select text in console.
 	 *
@@ -412,6 +511,17 @@ public final class IOConsoleTestUtil {
 		return this;
 	}
 
+	/**
+	 * Select all content in console.
+	 *
+	 * @return this {@link IOConsoleTestUtil} to chain methods
+	 * @see StyledText#setSelection(int, int)
+	 */
+	public IOConsoleTestUtil selectAll() {
+		textPanel.selectAll();
+		return this;
+	}
+
 	/**
 	 * Check if console content equals the expected content.
 	 *
@@ -420,7 +530,7 @@ public final class IOConsoleTestUtil {
 	 */
 	public IOConsoleTestUtil verifyContent(String expectedContent) {
 		verifyContentByOffset(expectedContent, 0);
-		TestCase.assertEquals("More or less content in console as expected.", expectedContent.length(), doc.getLength());
+		assertEquals("More or less content in console as expected.", expectedContent.length(), doc.getLength());
 		return this;
 	}
 
@@ -438,9 +548,9 @@ public final class IOConsoleTestUtil {
 		try {
 			final IRegion line = doc.getLineInformation(l);
 			verifyContentByOffset(expectedContent, line.getOffset());
-			TestCase.assertEquals("Line " + l + " has wrong length.", expectedContent.length(), line.getLength());
+			assertEquals("Line " + l + " has wrong length.", expectedContent.length(), line.getLength());
 		} catch (BadLocationException e) {
-			TestCase.fail("Expected line not found in console document. Bad location!");
+			fail("Expected line " + lineNum + " not found in console document. Bad location!");
 		}
 		return this;
 	}
@@ -457,9 +567,9 @@ public final class IOConsoleTestUtil {
 		try {
 			final int o = offset < 0 ? doc.getLength() + offset : offset;
 			final int len = Math.min(doc.getLength() - o, expectedContent.length());
-			TestCase.assertEquals("Expected string not found in console document.", expectedContent, doc.get(o, len));
+			assertEquals("Expected string not found in console document.", expectedContent, doc.get(o, len));
 		} catch (BadLocationException ex) {
-			TestCase.fail("Expected string not found in console document. Bad location!");
+			fail("Expected string '" + expectedContent + "' not found in console document. Bad location!");
 		}
 		return this;
 	}
@@ -525,8 +635,8 @@ public final class IOConsoleTestUtil {
 	public IOConsoleTestUtil verifyPartitions(final int offset, final int length, final String expectedType, final boolean allowMixedTypes, final boolean allowGaps, int minPartitionNumber) {
 		{
 			final ITypedRegion[] partitions = getPartitioner().computePartitioning(offset, length);
-			TestCase.assertNotNull("Got no partitions.", partitions);
-			TestCase.assertTrue("Got less partitions than expected.", partitions.length >= minPartitionNumber);
+			assertNotNull("Got no partitions.", partitions);
+			assertTrue("Got less partitions than expected.", partitions.length >= minPartitionNumber);
 
 			// points to offset after last partition range aka. expected start
 			// of next partition
@@ -534,13 +644,13 @@ public final class IOConsoleTestUtil {
 			ITypedRegion lastPartition = null;
 			String partitionType = expectedType;
 			for (ITypedRegion partition : partitions) {
-				TestCase.assertNotSame("Got same partition twice.", lastPartition, partition);
-				TestCase.assertTrue("Partition overlapping. (or not sorted as expected)", partition.getOffset() >= lastEnd);
+				assertNotSame("Got same partition twice.", lastPartition, partition);
+				assertTrue("Partition overlapping. (or not sorted as expected)", partition.getOffset() >= lastEnd);
 				if (!allowGaps && lastEnd != -1) {
-					TestCase.assertTrue("Partitioning gap.", partition.getOffset() == lastEnd);
+					assertTrue("Partitioning gap.", partition.getOffset() == lastEnd);
 				}
-				TestCase.assertTrue("Not a valid partition type.", validPartionTypes.contains(partition.getType()));
-				TestCase.assertTrue("Wrong partition type.", partitionType == null || partitionType.equals(partition.getType()) || allowMixedTypes);
+				assertTrue("Not a valid partition type.", validPartionTypes.contains(partition.getType()));
+				assertTrue("Wrong partition type.", partitionType == null || partitionType.equals(partition.getType()) || allowMixedTypes);
 				if (partitionType == null && !allowMixedTypes) {
 					partitionType = partition.getType();
 				}
@@ -548,34 +658,32 @@ public final class IOConsoleTestUtil {
 				lastPartition = partition;
 			}
 		}
-		{
-			int pos = offset;
-			int end = offset + length;
-			ITypedRegion lastPartition = null;
-			String partitionType = expectedType;
-			while (pos < end) {
-				final ITypedRegion partition = getPartitioner().getPartition(pos);
-				if (partition == null) {
-					TestCase.assertTrue("Did not expect 'null' partition.", allowGaps);
-					pos++;
-					continue;
-				}
-				TestCase.assertNotSame("Got same partition again.", lastPartition, partition);
-				TestCase.assertFalse("Did not expected and cannot handle empty partition.", partition.getLength() == 0);
-				TestCase.assertTrue("Got not the requested partition.", partition.getOffset() <= pos && partition.getOffset() + partition.getLength() > pos);
-				TestCase.assertTrue("Not a valid partition type.", validPartionTypes.contains(partition.getType()));
-				lastPartition = partition;
-				if (partitionType != null && !partitionType.equals(partition.getType())) {
-					TestCase.assertTrue("Wrong partition type.", allowMixedTypes);
-					pos += partition.getLength();
-					end += partition.getLength();
-					continue;
-				}
-				if (partitionType == null && !allowMixedTypes) {
-					partitionType = partition.getType();
-				}
-				pos = partition.getOffset() + partition.getLength();
+		int pos = offset;
+		int end = offset + length;
+		ITypedRegion lastPartition = null;
+		String partitionType = expectedType;
+		while (pos < end) {
+			final ITypedRegion partition = getPartitioner().getPartition(pos);
+			if (partition == null) {
+				assertTrue("Did not expect 'null' partition.", allowGaps);
+				pos++;
+				continue;
 			}
+			assertNotSame("Got same partition again.", lastPartition, partition);
+			assertFalse("Did not expected and cannot handle empty partition.", partition.getLength() == 0);
+			assertTrue("Got not the requested partition.", partition.getOffset() <= pos && partition.getOffset() + partition.getLength() > pos);
+			assertTrue("Not a valid partition type.", validPartionTypes.contains(partition.getType()));
+			lastPartition = partition;
+			if (partitionType != null && !partitionType.equals(partition.getType())) {
+				assertTrue("Wrong partition type.", allowMixedTypes);
+				pos += partition.getLength();
+				end += partition.getLength();
+				continue;
+			}
+			if (partitionType == null && !allowMixedTypes) {
+				partitionType = partition.getType();
+			}
+			pos = partition.getOffset() + partition.getLength();
 		}
 		return this;
 	}
@@ -602,6 +710,18 @@ public final class IOConsoleTestUtil {
 		return this;
 	}
 
+	/**
+	 * Ensure all pending write operations are fully applied on the console view
+	 * before returning.
+	 *
+	 * @return this {@link IOConsoleTestUtil} to chain methods
+	 */
+	public IOConsoleTestUtil flush() {
+		// overall this method is just a better name for waitForScheduledJobs
+		waitForScheduledJobs();
+		return this;
+	}
+
 	/**
 	 * Close the default output stream if it was used.
 	 */
@@ -610,7 +730,7 @@ public final class IOConsoleTestUtil {
 			try {
 				defaultOut.close();
 			} catch (IOException e) {
-				TestCase.fail("Failed to close output stream.");
+				fail("Failed to close output stream.");
 			}
 		}
 	}
@@ -643,6 +763,33 @@ public final class IOConsoleTestUtil {
 		return defaultOut;
 	}
 
+	/**
+	 * If <code>true</code> the util will work as if console is not in fixed
+	 * width mode. E.g. {@link #moveCaretToLineStart()} will move caret to
+	 * document line start not to widget line start or
+	 * {@link #verifyContentByLine(String, int)} would check the line as seen
+	 * without fixed width.
+	 *
+	 * @see #ignoreFixedConsole
+	 */
+	public boolean isIgnoreFixedConsole() {
+		return ignoreFixedConsole;
+	}
+
+	/**
+	 * Enable compatibility mode. If set to <code>true</code> tests written for
+	 * console without fixed width should work with any fixed width. Commands
+	 * like {@link #moveCaretToLineStart()} are modified to not move to begin of
+	 * widget line (maybe wrapped line) but to start it would have without fixed
+	 * width or {@link #verifyContentByLine(String, int)} would check the line
+	 * as seen without fixed width.
+	 *
+	 * @see #ignoreFixedConsole
+	 */
+	public void setIgnoreFixedConsole(boolean ignoreWrappeding) {
+		this.ignoreFixedConsole = ignoreWrappeding;
+	}
+
 	/**
 	 * Get identifier for output {@link IOConsolePartition}s.
 	 *
