@@ -46,8 +46,7 @@ public abstract class SelectAllAction extends AbstractRemoveAllActionDelegate {
 	protected abstract String getActionId();
 
 	private void collectExpandedAndVisible(TreeItem[] items, List<TreeItem> result) {
-		for (int i= 0; i < items.length; i++) {
-			TreeItem item= items[i];
+		for (TreeItem item : items) {
 			result.add(item);
 			if (item.getExpanded()) {
 				collectExpandedAndVisible(item.getItems(), result);
