@@ -27,15 +27,11 @@ import org.eclipse.debug.internal.ui.views.breakpoints.BreakpointsView;
 import org.eclipse.jface.dialogs.Dialog;
 import org.eclipse.jface.dialogs.TrayDialog;
 import org.eclipse.jface.resource.ImageDescriptor;
-import org.eclipse.jface.viewers.DoubleClickEvent;
-import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ILabelProvider;
-import org.eclipse.jface.viewers.ISelectionChangedListener;
 import org.eclipse.jface.viewers.IStructuredContentProvider;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.jface.viewers.ITreeContentProvider;
 import org.eclipse.jface.viewers.LabelProvider;
-import org.eclipse.jface.viewers.SelectionChangedEvent;
 import org.eclipse.jface.viewers.TableViewer;
 import org.eclipse.jface.viewers.TreeViewer;
 import org.eclipse.jface.viewers.Viewer;
@@ -113,7 +109,7 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 		Composite composite= new Composite(parentComposite, SWT.NONE);
 		GridLayout layout = new GridLayout();
 		layout.numColumns = 3;
-        composite.setLayout(layout);
+		composite.setLayout(layout);
 		GridData data= new GridData(GridData.FILL_BOTH);
 		data.heightHint= 400;
 		composite.setLayoutData(data);
@@ -123,7 +119,7 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 		label.setText(BreakpointGroupMessages.GroupBreakpointsByDialog_0);
 		GridData gridData = new GridData(GridData.FILL_HORIZONTAL);
 		gridData.horizontalSpan = 3;
-        label.setLayoutData(gridData);
+		label.setLayoutData(gridData);
 
 		createAvailableViewer(composite, labelProvider);
 		createButtons(composite);
@@ -148,15 +144,15 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 	 */
 	private void initializeContent() {
 		IBreakpointOrganizer[] organizers= BreakpointOrganizerManager.getDefault().getOrganizers();
-		for (int i = 0; i < organizers.length; i++) {
-			fAvailableOrganizersProvider.addAvailable(organizers[i]);
+		for (IBreakpointOrganizer organizer : organizers) {
+			fAvailableOrganizersProvider.addAvailable(organizer);
 		}
 		organizers = fView.getBreakpointOrganizers();
-        if (organizers != null) {
-    		for (int i = 0; i < organizers.length; i++) {
-                fSelectedOrganizersProvider.addSelected(organizers[i]);
-            }
-        }
+		if (organizers != null) {
+			for (IBreakpointOrganizer organizer : organizers) {
+				fSelectedOrganizersProvider.addSelected(organizer);
+			}
+		}
 	}
 
 	/**
@@ -177,7 +173,7 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 		Label label= new Label(availableComposite, SWT.WRAP);
 		label.setText(BreakpointGroupMessages.GroupBreakpointsByDialog_1);
 		gridData = new GridData(GridData.FILL_HORIZONTAL);
-        label.setLayoutData(gridData);
+		label.setLayoutData(gridData);
 
 		fAvailableViewer= new TableViewer(availableComposite);
 		fAvailableViewer.setContentProvider(fAvailableOrganizersProvider);
@@ -186,18 +182,8 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 		Table table = fAvailableViewer.getTable();
 		table.setLayoutData(new GridData(GridData.FILL_BOTH));
 		table.setFont(parent.getFont());
-		fAvailableViewer.addDoubleClickListener(new IDoubleClickListener() {
-			@Override
-			public void doubleClick(DoubleClickEvent event) {
-				handleAddPressed();
-			}
-		});
-		fAvailableViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				updateAddButton();
-			}
-		});
+		fAvailableViewer.addDoubleClickListener(event -> handleAddPressed());
+		fAvailableViewer.addSelectionChangedListener(event -> updateAddButton());
 	}
 
 	/**
@@ -220,7 +206,7 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 		label.setText(BreakpointGroupMessages.GroupBreakpointsByDialog_3);
 		gridData = new GridData();
 		gridData.horizontalSpan = 2;
-        label.setLayoutData(gridData);
+		label.setLayoutData(gridData);
 
 		fSelectedViewer= new TreeViewer(selectedComposite);
 		fSelectedViewer.setContentProvider(fSelectedOrganizersProvider);
@@ -229,18 +215,8 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 		Tree tree = fSelectedViewer.getTree();
 		tree.setLayoutData(new GridData(GridData.FILL_BOTH));
 		tree.setFont(parent.getFont());
-		fSelectedViewer.addDoubleClickListener(new IDoubleClickListener() {
-            @Override
-			public void doubleClick(DoubleClickEvent event) {
-                handleRemovePressed();
-            }
-        });
-		fSelectedViewer.addSelectionChangedListener(new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				updateSelectedButtons();
-			}
-		});
+		fSelectedViewer.addDoubleClickListener(event -> handleRemovePressed());
+		fSelectedViewer.addSelectionChangedListener(event -> updateSelectedButtons());
 	}
 
 	public void createButtons(Composite parent) {
@@ -405,13 +381,13 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 
 	/**
 	 * Content provider that provides the list of breakpoint organaisers
-     * that are available but not currently selected.
+	 * that are available but not currently selected.
 	 */
 	private class AvailableOrganizersProvider implements IStructuredContentProvider {
 		protected List<IBreakpointOrganizer> availableOrganziers = new ArrayList<>();
 
 		public void addAvailable(IBreakpointOrganizer organizer) {
-            availableOrganziers.add(organizer);
+			availableOrganziers.add(organizer);
 			fSelectedOrganizersProvider.selectedOrganizers.remove(organizer);
 		}
 
@@ -437,23 +413,23 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 		protected List<Object> selectedOrganizers = new ArrayList<>();
 
 		public void addSelected(IBreakpointOrganizer organizer) {
-            selectedOrganizers.add(organizer);
+			selectedOrganizers.add(organizer);
 			fAvailableOrganizersProvider.availableOrganziers.remove(organizer);
 		}
 
 		public void moveUp(Object object) {
 			int index = selectedOrganizers.indexOf(object);
 			if (index > 0) {
-                selectedOrganizers.remove(object);
-                selectedOrganizers.add(index - 1, object);
+				selectedOrganizers.remove(object);
+				selectedOrganizers.add(index - 1, object);
 			}
 		}
 
 		public void moveDown(Object object) {
 			int index = selectedOrganizers.indexOf(object);
 			if (index < selectedOrganizers.size() - 1) {
-                selectedOrganizers.remove(object);
-                selectedOrganizers.add(index + 1, object);
+				selectedOrganizers.remove(object);
+				selectedOrganizers.add(index + 1, object);
 			}
 		}
 
@@ -533,9 +509,9 @@ public class GroupBreakpointsByDialog extends TrayDialog {
 		}
 	}
 
-    @Override
+	@Override
 	protected void configureShell(Shell shell) {
-        super.configureShell(shell);
-        shell.setText(BreakpointGroupMessages.GroupBreakpointsByDialog_7);
-    }
+		super.configureShell(shell);
+		shell.setText(BreakpointGroupMessages.GroupBreakpointsByDialog_7);
+	}
 }
