@@ -51,8 +51,8 @@ public class EnableWatchExpressionAction implements IViewActionDelegate, IAction
 			while (iter.hasNext()) {
 				expression= getWatchExpression(iter.next());
 				if (expression != null) {
-    				expression.setEnabled(fEnable);
-    				fireWatchExpressionChanged(expression);
+					expression.setEnabled(fEnable);
+					fireWatchExpressionChanged(expression);
 				}
 			}
 		} else if (fSelection instanceof IWatchExpression) {
@@ -92,12 +92,12 @@ public class EnableWatchExpressionAction implements IViewActionDelegate, IAction
 	}
 
 	private IWatchExpression getWatchExpression(Object element) {
-	    if (element instanceof IWatchExpression) {
-	        return (IWatchExpression)element;
-	    } else if (element instanceof IAdaptable) {
-	        return ((IAdaptable)element).getAdapter(IWatchExpression.class);
-	    }
-	    return null;
+		if (element instanceof IWatchExpression) {
+			return (IWatchExpression)element;
+		} else if (element instanceof IAdaptable) {
+			return ((IAdaptable)element).getAdapter(IWatchExpression.class);
+		}
+		return null;
 	}
 
 	@Override
@@ -117,8 +117,7 @@ public class EnableWatchExpressionAction implements IViewActionDelegate, IAction
 
 	@Override
 	public void handleDebugEvents(DebugEvent[] events) {
-		for (int i = 0; i < events.length; i++) {
-			DebugEvent event = events[i];
+		for (DebugEvent event : events) {
 			if (event.getSource() instanceof IWatchExpression) {
 				if (event.getKind() == DebugEvent.CHANGE) {
 					selectionChanged(fAction, fSelection);
