@@ -115,11 +115,11 @@ public class DebugContextManager implements IDebugContextManager {
 
 		@Override
 		public void windowClosed(final IWorkbenchWindow window) {
-            DebugWindowContextService service = fServices.get(window);
-            if (service != null) {
-            	fServices.remove(window);
-                service.dispose();
-            }
+			DebugWindowContextService service = fServices.get(window);
+			if (service != null) {
+				fServices.remove(window);
+				service.dispose();
+			}
 		}
 
 		@Override
@@ -146,6 +146,10 @@ public class DebugContextManager implements IDebugContextManager {
 	protected IDebugContextService createService(IWorkbenchWindow window) {
 		DebugWindowContextService service = fServices.get(window);
 		if (service == null) {
+			if (window == null) {
+				// the window has been closed - return a dummy service
+				return NULL_SERVICE;
+			}
 			IEvaluationService evaluationService = window.getService(IEvaluationService.class);
 			if (window.getShell() == null || evaluationService == null) {
 				// the window has been closed - return a dummy service
@@ -170,8 +174,7 @@ public class DebugContextManager implements IDebugContextManager {
 	public void addDebugContextListener(IDebugContextListener listener) {
 		fGlobalListeners.add(listener);
 		DebugWindowContextService[] services = getServices();
-		for (int i = 0; i < services.length; i++) {
-			DebugWindowContextService service = services[i];
+		for (DebugWindowContextService service : services) {
 			service.addDebugContextListener(listener);
 		}
 	}
@@ -180,8 +183,7 @@ public class DebugContextManager implements IDebugContextManager {
 	public void removeDebugContextListener(IDebugContextListener listener) {
 		fGlobalListeners.remove(listener);
 		DebugWindowContextService[] services = getServices();
-		for (int i = 0; i < services.length; i++) {
-			DebugWindowContextService service = services[i];
+		for (DebugWindowContextService service : services) {
 			service.removeDebugContextListener(listener);
 		}
 	}
