@@ -205,8 +205,7 @@ public class SourceLookupFacility implements IPageListener, IPartListener2, IPro
 	@Override
 	public void handleDebugEvents(DebugEvent[] events) {
 		IStackFrame frame = null;
-		for (int i = 0; i < events.length; i++) {
-			final DebugEvent event = events[i];
+		for (DebugEvent event : events) {
 			switch (event.getKind()) {
 				case DebugEvent.TERMINATE:
 				case DebugEvent.RESUME:
@@ -374,15 +373,15 @@ public class SourceLookupFacility implements IPageListener, IPartListener2, IPro
 			}
 		}
 		return result;
-    }
+	}
 
-    /**
-     * Returns the model presentation for the given debug model, or <code>null</code>
-     * if none.
-     *
-     * @param id debug model id
-     * @return presentation for the model, or <code>null</code> if none.
-     */
+	/**
+	 * Returns the model presentation for the given debug model, or <code>null</code>
+	 * if none.
+	 *
+	 * @param id debug model id
+	 * @return presentation for the model, or <code>null</code> if none.
+	 */
 	protected IDebugModelPresentation getPresentation(String id) {
 		return ((DelegatingModelPresentation)DebugUIPlugin.getModelPresentation()).getPresentation(id);
 	}
@@ -393,32 +392,32 @@ public class SourceLookupFacility implements IPageListener, IPartListener2, IPro
 	 * @return an editor presentation
 	 */
 	protected IDebugEditorPresentation getEditorPresentation() {
-	    return (DelegatingModelPresentation)DebugUIPlugin.getModelPresentation();
+		return (DelegatingModelPresentation)DebugUIPlugin.getModelPresentation();
 	}
 
-    /**
-     * Opens an editor in the given workbench page for the given source lookup
-     * result. Has no effect if the result has an unknown editor id or editor input.
-     * The editor is opened, positioned, and annotated.
-     * <p>
-     * Honor's the user preference of whether to re-use editors when displaying source.
-     * </p>
-     * @param result source lookup result to display
-     * @param page the page to display the result in
-     */
-    public void display(ISourceLookupResult result, IWorkbenchPage page) {
+	/**
+	 * Opens an editor in the given workbench page for the given source lookup
+	 * result. Has no effect if the result has an unknown editor id or editor input.
+	 * The editor is opened, positioned, and annotated.
+	 * <p>
+	 * Honor's the user preference of whether to re-use editors when displaying source.
+	 * </p>
+	 * @param result source lookup result to display
+	 * @param page the page to display the result in
+	 */
+	public void display(ISourceLookupResult result, IWorkbenchPage page) {
 		IEditorPart editor= openEditor(result, page);
 		if (editor == null) {
 			return;
 		}
 		IStackFrame frame = null;
-        if (result.getArtifact() instanceof IStackFrame) {
-            frame = (IStackFrame) result.getArtifact();
-        }
+		if (result.getArtifact() instanceof IStackFrame) {
+			frame = (IStackFrame) result.getArtifact();
+		}
 		// position and annotate editor for stack frame
-        if (frame != null) {
+		if (frame != null) {
 			IDebugEditorPresentation editorPresentation = getEditorPresentation();
-            if (editorPresentation.addAnnotations(editor, frame)) {
+			if (editorPresentation.addAnnotations(editor, frame)) {
 				Decoration decoration = new StandardDecoration(editorPresentation, editor, frame.getThread());
 				DecorationManager.addDecoration(decoration);
 			} else {
@@ -439,7 +438,7 @@ public class SourceLookupFacility implements IPageListener, IPartListener2, IPro
 				}
 			}
 		}
-    }
+	}
 
 	/**
 	 * Opens the editor used to display the source for an element selected in
@@ -463,20 +462,20 @@ public class SourceLookupFacility implements IPageListener, IPartListener2, IPro
 				page.bringToTop(editor);
 			}
 			if (editor == null) {
-			    IEditorPart editorForPage = getEditor(page);
+				IEditorPart editorForPage = getEditor(page);
 				if (editorForPage == null || editorForPage.isDirty() || page.isEditorPinned(editorForPage)) {
-				    // open a new editor
+					// open a new editor
 					editor = openEditor(page, input, id);
 					editorForPage = editor;
 				} else if (editorForPage instanceof IReusableEditor && editorForPage.getSite().getId().equals(id)) {
-				    // re-use editor
+					// re-use editor
 					page.reuseEditor((IReusableEditor)editorForPage, input);
 					editor = editorForPage;
-                    if(!page.isPartVisible(editor)) {
-                        page.bringToTop(editor);
-                    }
+					if(!page.isPartVisible(editor)) {
+						page.bringToTop(editor);
+					}
 				} else {
-				    // close editor, open a new one
+					// close editor, open a new one
 					editor = openEditor(page, input, id);
 					page.closeEditor(editorForPage, false);
 					editorForPage = editor;
@@ -569,108 +568,108 @@ public class SourceLookupFacility implements IPageListener, IPartListener2, IPro
 		return false;
 	}
 
-    @Override
+	@Override
 	public void pageActivated(IWorkbenchPage page) {
-    }
+	}
 
-    @Override
+	@Override
 	public void pageClosed(IWorkbenchPage page) {
-        fEditorsByPage.remove(page);
-        page.removePartListener(this);
-    }
+		fEditorsByPage.remove(page);
+		page.removePartListener(this);
+	}
 
-    @Override
+	@Override
 	public void pageOpened(IWorkbenchPage page) {
-    	page.addPartListener(this);
-    }
+		page.addPartListener(this);
+	}
 
-    @Override
+	@Override
 	public void partActivated(IWorkbenchPartReference partRef) {
-    }
+	}
 
-    @Override
+	@Override
 	public void partBroughtToTop(IWorkbenchPartReference partRef) {
-    }
+	}
 
-    @Override
+	@Override
 	public void partClosed(IWorkbenchPartReference partRef) {
-        // clear the cached editor for the page if it has been closed
-        IWorkbenchPage page = partRef.getPage();
-        IEditorPart editor = getEditor(page);
-        IWorkbenchPart part = partRef.getPart(false);
+		// clear the cached editor for the page if it has been closed
+		IWorkbenchPage page = partRef.getPage();
+		IEditorPart editor = getEditor(page);
+		IWorkbenchPart part = partRef.getPart(false);
 		if (part != null && part.equals(editor)) {
 			fEditorsByPage.remove(page);
 		}
-    }
+	}
 
-    @Override
+	@Override
 	public void partDeactivated(IWorkbenchPartReference partRef) {
-    }
+	}
 
-    @Override
+	@Override
 	public void partOpened(IWorkbenchPartReference partRef) {
-    }
+	}
 
-    @Override
+	@Override
 	public void partHidden(IWorkbenchPartReference partRef) {
-    }
+	}
 
-    @Override
+	@Override
 	public void partVisible(IWorkbenchPartReference partRef) {
-    }
+	}
 
-    @Override
+	@Override
 	public void partInputChanged(IWorkbenchPartReference partRef) {
-    }
+	}
 
-    @Override
+	@Override
 	public void propertyChange(PropertyChangeEvent event) {
-        String property = event.getProperty();
+		String property = event.getProperty();
 		if (property.equals(IDebugUIConstants.PREF_REUSE_EDITOR)) {
 			fReuseEditor = DebugUIPlugin.getDefault().getPreferenceStore().getBoolean(IDebugUIConstants.PREF_REUSE_EDITOR);
 		}
-    }
+	}
 
-    /**
-     * Returns the editor to use to display source in the given page, or
-     * <code>null</code> if a new editor should be opened.
-     *
-     * @param page workbench page
-     * @return the editor to use to display source in the given page, or
-     * <code>null</code> if a new editor should be opened
-     */
-    protected IEditorPart getEditor(IWorkbenchPage page) {
-        return fEditorsByPage.get(page);
-    }
+	/**
+	 * Returns the editor to use to display source in the given page, or
+	 * <code>null</code> if a new editor should be opened.
+	 *
+	 * @param page workbench page
+	 * @return the editor to use to display source in the given page, or
+	 * <code>null</code> if a new editor should be opened
+	 */
+	protected IEditorPart getEditor(IWorkbenchPage page) {
+		return fEditorsByPage.get(page);
+	}
 
-    /**
-     * Sets the editor to use to display source in the given page, or
-     * <code>null</code> if a new editor should be opened.
-     *
-     * @param page workbench page
-     * @return the editor to use to display source in the given page, or
-     * <code>null</code> if a new editor should be opened
-     */
-    protected void setEditor(IWorkbenchPage page, IEditorPart editorPart) {
-        if (editorPart == null) {
-            fEditorsByPage.remove(page);
-        } else {
-            fEditorsByPage.put(page, editorPart);
-        }
-        page.addPartListener(this);
-        page.getWorkbenchWindow().addPageListener(this);
-    }
+	/**
+	 * Sets the editor to use to display source in the given page, or
+	 * <code>null</code> if a new editor should be opened.
+	 *
+	 * @param page workbench page
+	 * @return the editor to use to display source in the given page, or
+	 * <code>null</code> if a new editor should be opened
+	 */
+	protected void setEditor(IWorkbenchPage page, IEditorPart editorPart) {
+		if (editorPart == null) {
+			fEditorsByPage.remove(page);
+		} else {
+			fEditorsByPage.put(page, editorPart);
+		}
+		page.addPartListener(this);
+		page.getWorkbenchWindow().addPageListener(this);
+	}
 
-    /**
-     * Performs cleanup.
-     */
-    protected void dispose() {
-        DebugUIPlugin.getDefault().getPreferenceStore().removePropertyChangeListener(this);
+	/**
+	 * Performs cleanup.
+	 */
+	protected void dispose() {
+		DebugUIPlugin.getDefault().getPreferenceStore().removePropertyChangeListener(this);
 		DebugPlugin.getDefault().removeDebugEventListener(this);
-        fEditorsByPage.clear();
-        fPresentation.dispose();
+		fEditorsByPage.clear();
+		fPresentation.dispose();
 		fLookupResults.clear();
-    }
+	}
 
 	/**
 	 * A job to perform source lookup on the currently selected stack frame.
