@@ -14,6 +14,8 @@
  *******************************************************************************/
 package org.eclipse.debug.internal.ui.stringsubstitution;
 
+import java.text.MessageFormat;
+
 import org.eclipse.core.runtime.CoreException;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Status;
@@ -23,8 +25,6 @@ import org.eclipse.debug.core.DebugException;
 import org.eclipse.debug.internal.ui.DebugUIPlugin;
 import org.eclipse.swt.widgets.Shell;
 
-import com.ibm.icu.text.MessageFormat;
-
 /**
  * Base implementation for variable resolvers that prompt the user
  * for their value.
@@ -94,7 +94,7 @@ abstract class PromptingResolver implements IDynamicVariableResolver {
 		String value = null;
 		setupDialog(argument);
 
-		DebugUIPlugin.getStandardDisplay().syncExec(() -> prompt());
+		DebugUIPlugin.getStandardDisplay().syncExec(this::prompt);
 		if (dialogResultString != null) {
 			value = dialogResultString;
 			lastValue = dialogResultString;
