@@ -36,9 +36,7 @@ import org.eclipse.debug.ui.memory.IMemoryRenderingBindingsListener;
 import org.eclipse.debug.ui.memory.IMemoryRenderingContainer;
 import org.eclipse.debug.ui.memory.IMemoryRenderingType;
 import org.eclipse.jface.util.PropertyChangeEvent;
-import org.eclipse.jface.viewers.DoubleClickEvent;
 import org.eclipse.jface.viewers.IBasicPropertyConstants;
-import org.eclipse.jface.viewers.IDoubleClickListener;
 import org.eclipse.jface.viewers.ILabelProvider;
 import org.eclipse.jface.viewers.ILabelProviderListener;
 import org.eclipse.jface.viewers.ISelection;
@@ -96,7 +94,7 @@ public class CreateRendering extends AbstractMemoryRendering implements IMemoryR
 				String label = ((IMemoryRenderingType)element).getLabel();
 				return label;
 			}
-            return element.toString();
+			return element.toString();
 		}
 
 		@Override
@@ -186,12 +184,7 @@ public class CreateRendering extends AbstractMemoryRendering implements IMemoryR
 		listLayout.horizontalSpan = 1;
 		fViewer.getControl().setLayoutData(listLayout);
 
-		fViewer.addDoubleClickListener(new IDoubleClickListener (){
-
-			@Override
-			public void doubleClick(DoubleClickEvent event) {
-				addRenderings();
-			}});
+		fViewer.addDoubleClickListener(event -> addRenderings());
 
 		// listen for enter being pressed
 		fViewer.getList().addKeyListener(new KeyAdapter() {
@@ -257,12 +250,10 @@ public class CreateRendering extends AbstractMemoryRendering implements IMemoryR
 		// make a copy of the container, may be diposed when a rendering is added
 		IMemoryRenderingContainer container = fContainer;
 		// add memory renderings to Memory Rendering Manager
-		for (int i=0; i<renderings.length; i++)
-		{
-			if (renderings[i] instanceof IMemoryRenderingType)
-			{
+		for (Object r : renderings) {
+			if (r instanceof IMemoryRenderingType) {
 				try {
-					IMemoryRendering rendering = ((IMemoryRenderingType)renderings[i]).createRendering();
+					IMemoryRendering rendering = ((IMemoryRenderingType) r).createRendering();
 					if (rendering != null)
 					{
 						rendering.init(container, getMemoryBlock());
