@@ -37,34 +37,31 @@ public class UnsignedIntegerRendering extends AbstractIntegerRendering {
 		String ret;
 		long result = 0;
 
-		if (columnSize == 1)
-		{
+		switch (columnSize) {
+		case 1:
 			result = byteArray[0];
 			result &= 0xff;
-		}
-		else if (columnSize == 2)
-		{
+			break;
+		case 2:
 			result = RenderingsUtil.convertByteArrayToInt(byteArray, endianess);
-		}
-		else if (columnSize == 4)
-		{
+			break;
+		case 4:
 			result = RenderingsUtil.convertByteArrayToLong(byteArray, endianess);
-		}
-		else if (columnSize == 8)
-		{
+			break;
+		case 8:
 			BigInteger value = RenderingsUtil.convertByteArrayToUnsignedLong(byteArray, endianess);
 			return value.toString();
-		}
-		else if (columnSize == 16)
+		case 16:
 		{
 			BigInteger bigRet = RenderingsUtil.convertByteArrayToUnsignedBigInt(byteArray, endianess);
 			return bigRet.toString();
 		}
-		else
+		default:
 		{
 			BigInteger bigRet = RenderingsUtil.convertByteArrayToUnsignedBigInt(byteArray, endianess, columnSize);
 			return bigRet.toString();
 		}
+		}
 
 		ret = Long.valueOf(result).toString();
 
@@ -75,32 +72,37 @@ public class UnsignedIntegerRendering extends AbstractIntegerRendering {
 	{
 		try {
 			byte[] bytes;
-			if (colSize == 1)
+			switch (colSize) {
+			case 1:
 			{
 				short i = Short.parseShort(newValue);
 				bytes = RenderingsUtil.convertShortToByteArray(i, endianess);
 				bytes = extractBytes(bytes, endianess, colSize);
+				break;
 			}
 			// unsigned integer
-			else if (colSize == 2)
+			case 2:
 			{
 				int i = Integer.parseInt(newValue);
 				bytes = RenderingsUtil.convertIntToByteArray(i, endianess);
 				bytes = extractBytes(bytes, endianess, colSize);
+				break;
 			}
-			else if (colSize == 4)
+			case 4:
 			{
 				long i = Long.parseLong(newValue);
 				bytes = RenderingsUtil.convertLongToByteArray(i, endianess);
 				bytes = extractBytes(bytes, endianess, colSize);
+				break;
 			}
-			else if (colSize == 8)
+			case 8:
 			{
 				BigInteger i = new BigInteger(newValue);
 				bytes = RenderingsUtil.convertBigIntegerToByteArray(i, endianess);
 				bytes = extractBytes(bytes, endianess, colSize);
+				break;
 			}
-			else if (colSize == 16)
+			case 16:
 			{
 				BigInteger i = new BigInteger(newValue);
 				bytes = RenderingsUtil.convertUnsignedBigIntegerToByteArray(i, endianess);
@@ -108,13 +110,14 @@ public class UnsignedIntegerRendering extends AbstractIntegerRendering {
 
 				return bytes;
 			}
-			else
+			default:
 			{
 				BigInteger i = new BigInteger(newValue);
 				bytes = RenderingsUtil.convertUnsignedBigIntToByteArray(i, endianess, colSize);
 				bytes = extractBytes(bytes, endianess, colSize);
 				return bytes;
 			}
+			}
 
 			return bytes;
 		} catch (NumberFormatException e) {
@@ -127,10 +130,8 @@ public class UnsignedIntegerRendering extends AbstractIntegerRendering {
 
 		String paddedStr = DebugUIPlugin.getDefault().getPreferenceStore().getString(IDebugUIConstants.PREF_PADDED_STR);
 		boolean invalid = false;
-		for (int i=0; i<data.length; i++)
-		{
-			if (!data[i].isReadable())
-			{
+		for (MemoryByte memByte : data) {
+			if (!memByte.isReadable()) {
 				invalid = true;
 				break;
 			}
@@ -138,7 +139,7 @@ public class UnsignedIntegerRendering extends AbstractIntegerRendering {
 
 		if (invalid)
 		{
-			StringBuffer strBuf = new StringBuffer();
+			StringBuilder strBuf = new StringBuilder();
 			for (int i=0; i<data.length; i++)
 			{
 				strBuf.append(paddedStr);
@@ -161,7 +162,7 @@ public class UnsignedIntegerRendering extends AbstractIntegerRendering {
 		// if endianess is unknown, do not render, just return padded string
 		if (RenderingsUtil.ENDIANESS_UNKNOWN == endianess)
 		{
-			StringBuffer strBuf = new StringBuffer();
+			StringBuilder strBuf = new StringBuilder();
 			for (int i=0; i<byteArray.length; i++)
 			{
 				strBuf.append(paddedStr);
