@@ -76,9 +76,9 @@ import org.eclipse.debug.ui.IDebugView;
 import org.eclipse.debug.ui.contexts.DebugContextEvent;
 import org.eclipse.debug.ui.contexts.IDebugContextListener;
 import org.eclipse.debug.ui.contexts.IDebugContextService;
+import org.eclipse.e4.ui.services.IStylingEngine;
 import org.eclipse.jface.action.Action;
 import org.eclipse.jface.action.IAction;
-import org.eclipse.jface.action.IMenuListener;
 import org.eclipse.jface.action.IMenuManager;
 import org.eclipse.jface.action.IStatusLineManager;
 import org.eclipse.jface.action.IToolBarManager;
@@ -86,6 +86,7 @@ import org.eclipse.jface.action.MenuManager;
 import org.eclipse.jface.action.Separator;
 import org.eclipse.jface.commands.ActionHandler;
 import org.eclipse.jface.preference.IPreferenceStore;
+import org.eclipse.jface.resource.FontDescriptor;
 import org.eclipse.jface.resource.JFaceResources;
 import org.eclipse.jface.util.IPropertyChangeListener;
 import org.eclipse.jface.util.LocalSelectionTransfer;
@@ -109,21 +110,21 @@ import org.eclipse.swt.events.ControlEvent;
 import org.eclipse.swt.events.ControlListener;
 import org.eclipse.swt.events.FocusAdapter;
 import org.eclipse.swt.events.FocusEvent;
+import org.eclipse.swt.graphics.Font;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
-import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Label;
 import org.eclipse.swt.widgets.Listener;
+import org.eclipse.swt.widgets.Tree;
 import org.eclipse.swt.widgets.TreeItem;
 import org.eclipse.swt.widgets.Widget;
 import org.eclipse.ui.IActionBars;
 import org.eclipse.ui.IMemento;
 import org.eclipse.ui.IPerspectiveDescriptor;
 import org.eclipse.ui.IPerspectiveListener;
-import org.eclipse.ui.IPropertyListener;
 import org.eclipse.ui.ISaveablePart2;
 import org.eclipse.ui.IViewSite;
 import org.eclipse.ui.IWorkbenchActionConstants;
@@ -131,6 +132,7 @@ import org.eclipse.ui.IWorkbenchPage;
 import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.IWorkbenchPartSite;
 import org.eclipse.ui.PartInitException;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.WorkbenchException;
 import org.eclipse.ui.XMLMemento;
 import org.eclipse.ui.handlers.CollapseAllHandler;
@@ -148,20 +150,19 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		IViewerUpdateListener, IDetailPaneContainer2, ISaveablePart2 {
 
 	private static final String COLLAPSE_ALL = "CollapseAll"; //$NON-NLS-1$
+	/**
+	 * Unique ID of variables view tree viewer used for CSS styling
+	 */
+	private static final String CSS_VARIABLES_VIEWER_ID = "VariablesViewer"; //$NON-NLS-1$
 
 	/**
-	 * Selection provider wrapping an exchangeable active selection provider.
-	 * Sends out a selection changed event when the active selection provider changes.
+	 * Selection provider wrapping an exchangeable active selection provider. Sends
+	 * out a selection changed event when the active selection provider changes.
 	 * Forwards all selection changed events of the active selection provider.
 	 */
 	private static class SelectionProviderWrapper implements ISelectionProvider {
 		private final ListenerList<ISelectionChangedListener> fListenerList = new ListenerList<>(ListenerList.IDENTITY);
-		private final ISelectionChangedListener fListener = new ISelectionChangedListener() {
-			@Override
-			public void selectionChanged(SelectionChangedEvent event) {
-				fireSelectionChanged(event);
-			}
-		};
+		private final ISelectionChangedListener fListener = this::fireSelectionChanged;
 		private ISelectionProvider fActiveProvider;
 
 		private SelectionProviderWrapper(ISelectionProvider provider) {
@@ -293,12 +294,9 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	 * Viewer input requester used to update the viewer once the viewer input has been
 	 * resolved.
 	 */
-	private IViewerInputRequestor fRequester = new IViewerInputRequestor() {
-		@Override
-		public void viewerInputComplete(IViewerInputUpdate update) {
-			if (!update.isCanceled()) {
-			    viewerInputUpdateComplete(update);
-			}
+	private IViewerInputRequestor fRequester = update -> {
+		if (!update.isCanceled()) {
+			viewerInputUpdateComplete(update);
 		}
 	};
 
@@ -313,7 +311,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	private ToggleDetailPaneAction[] fToggleDetailPaneActions;
 	private ConfigureColumnsAction fConfigureColumnsAction;
 
-    protected String PREF_STATE_MEMENTO = "pref_state_memento."; //$NON-NLS-1$
+	protected String PREF_STATE_MEMENTO = "pref_state_memento."; //$NON-NLS-1$
 
 	public static final String LOGICAL_STRUCTURE_TYPE_PREFIX = "VAR_LS_"; //$NON-NLS-1$
 
@@ -339,16 +337,16 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	 */
 	protected static final String DETAIL_PANE_TYPE = "DETAIL_PANE_TYPE"; //$NON-NLS-1$
 
-    /**
-     * Visits deltas to determine if details should be displayed
-     */
-    class Visitor implements IModelDeltaVisitor {
-        /**
-         * Whether to trigger details display.
-         *
-         * @since 3.3
-         */
-        private boolean fTriggerDetails = false;
+	/**
+	 * Visits deltas to determine if details should be displayed
+	 */
+	class Visitor implements IModelDeltaVisitor {
+		/**
+		 * Whether to trigger details display.
+		 *
+		 * @since 3.3
+		 */
+		private boolean fTriggerDetails = false;
 		@Override
 		public boolean visit(IModelDelta delta, int depth) {
 			if ((delta.getFlags() & IModelDelta.CONTENT) > 0) {
@@ -366,16 +364,16 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 			return fTriggerDetails;
 		}
 
-    }
-    /**
-     * Delta visitor
-     */
-    private Visitor fVisitor = new Visitor();
+	}
+	/**
+	 * Delta visitor
+	 */
+	private Visitor fVisitor = new Visitor();
 
-    /**
-     * Job to update details in the UI thread.
-     */
-    private Job fTriggerDetailsJob = new UIJob("trigger details") { //$NON-NLS-1$
+	/**
+	 * Job to update details in the UI thread.
+	 */
+	private Job fTriggerDetailsJob = new UIJob("trigger details") { //$NON-NLS-1$
 
 		@Override
 		public IStatus runInUIThread(IProgressMonitor monitor) {
@@ -397,6 +395,10 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	 */
 	private IPresentationContext fPresentationContext;
 
+	private Font variablesTreeFont;
+
+	private TreeModelViewer variablesViewer;
+
 	/**
 	 * Remove myself as a selection listener
 	 * and preference change listener.
@@ -406,7 +408,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	@Override
 	public void dispose() {
 
-        DebugUITools.removePartDebugContextListener(getSite(), this);
+		DebugUITools.removePartDebugContextListener(getSite(), this);
 		getSite().getWorkbenchWindow().removePerspectiveListener(this);
 		DebugUIPlugin.getDefault().getPreferenceStore().removePropertyChangeListener(this);
 		JFaceResources.getFontRegistry().removeListener(this);
@@ -416,14 +418,17 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 			viewer.removeViewerUpdateListener(this);
 		}
 		if (fPresentationContext != null) {
-		    fPresentationContext.dispose();
-		    fPresentationContext = null;
+			fPresentationContext.dispose();
+			fPresentationContext = null;
 		}
 		if (fDetailPane != null) {
 			fDetailPane.dispose();
 		}
-        fInputService.dispose();
-        fSelectionProvider.dispose();
+		fInputService.dispose();
+		fSelectionProvider.dispose();
+		if (variablesTreeFont != null) {
+			variablesTreeFont.dispose();
+		}
 		super.dispose();
 	}
 
@@ -435,8 +440,8 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	 * @param update Completed viewer input update.
 	 */
 	protected void viewerInputUpdateComplete(IViewerInputUpdate update) {
-	    setViewerInput(update.getInputElement());
-        updateAction(FIND_ACTION);
+		setViewerInput(update.getInputElement());
+		updateAction(FIND_ACTION);
 	}
 
 	/**
@@ -444,24 +449,24 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	 * @param context the object context
 	 */
 	protected void setViewerInput(Object context) {
-        if (context == null) {
-            // Clear the detail pane
-        	refreshDetailPaneContents();
-        }
+		if (context == null) {
+			// Clear the detail pane
+			refreshDetailPaneContents();
+		}
 
-        Object current = getViewer().getInput();
+		Object current = getViewer().getInput();
 
-        if (current == null && context == null) {
-            return;
-        }
+		if (current == null && context == null) {
+			return;
+		}
 
-        if (current != null && current.equals(context)) {
-            return;
-        }
+		if (current != null && current.equals(context)) {
+			return;
+		}
 
-        showViewer();
-        getViewer().setInput(context);
-        updateObjects();
+		showViewer();
+		getViewer().setInput(context);
+		updateObjects();
 	}
 
 	@Override
@@ -470,7 +475,11 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		if (propertyName.equals(IDebugUIConstants.PREF_CHANGED_DEBUG_ELEMENT_COLOR) ||
 				propertyName.equals(IDebugUIConstants.PREF_CHANGED_VALUE_BACKGROUND) ||
 				propertyName.equals(IDebugUIConstants.PREF_VARIABLE_TEXT_FONT)) {
-			getViewer().refresh();
+			Viewer viewer = getViewer();
+			if (viewer == variablesViewer) {
+				setVariablesViewerTreeFont(variablesViewer);
+			}
+			viewer.refresh();
 		}
 	}
 
@@ -487,10 +496,12 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		DebugUIPlugin.getDefault().getPreferenceStore().addPropertyChangeListener(this);
 		JFaceResources.getFontRegistry().addListener(this);
 
-		TreeModelViewer variablesViewer = createTreeViewer(fSashForm);
+		variablesViewer = createTreeViewer(fSashForm);
 		fInputService = new ViewerInputService(variablesViewer, fRequester);
 
 		fSashForm.setMaximizedControl(variablesViewer.getControl());
+		setVariablesViewerTreeFont(variablesViewer);
+
 		fDetailsAnchor = SWTFactory.createComposite(fSashForm, parent.getFont(), 1, 1, GridData.FILL_BOTH, 0, 0);
 		fSashForm.setWeights(getLastSashWeights());
 
@@ -500,17 +511,12 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		createOrientationActions(variablesViewer);
 		IPreferenceStore prefStore = DebugUIPlugin.getDefault().getPreferenceStore();
 		String orientation = prefStore.getString(getDetailPanePreferenceKey());
-		for (int i = 0; i < fToggleDetailPaneActions.length; i++) {
-			fToggleDetailPaneActions[i].setChecked(fToggleDetailPaneActions[i].getOrientation().equals(orientation));
+		for (ToggleDetailPaneAction action : fToggleDetailPaneActions) {
+			action.setChecked(action.getOrientation().equals(orientation));
 		}
 
 		fDetailPane = new DetailPaneProxy(this);
-		fDetailPane.addProperyListener(new IPropertyListener() {
-			@Override
-			public void propertyChanged(Object source, int propId) {
-				firePropertyChange(propId);
-			}
-		});
+		fDetailPane.addProperyListener((source, propId) -> firePropertyChange(propId));
 		setDetailPaneOrientation(orientation);
 
 		IMemento memento = getMemento();
@@ -521,39 +527,54 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		variablesViewer.addModelChangedListener(this);
 		variablesViewer.addViewerUpdateListener(this);
 
-        initDragAndDrop(variablesViewer);
+		initDragAndDrop(variablesViewer);
 
 		return variablesViewer;
 	}
 
-    /**
-     * Initializes the drag and/or drop adapters for this view.  Called from createViewer().
-     *
-     * @param viewer the viewer to add drag/drop support to.
-     * @since 3.4
-     */
-    protected void initDragAndDrop(TreeModelViewer viewer) {
-        // Drag only
-        viewer.addDragSupport(DND.DROP_COPY, new Transfer[] {LocalSelectionTransfer.getTransfer()}, new SelectionDragAdapter(viewer));
-    }
+	private void setVariablesViewerTreeFont(TreeModelViewer variablesViewer) {
+		Tree tree = variablesViewer.getTree();
+		FontDescriptor fontDescriptor = JFaceResources.getFontDescriptor(IDebugUIConstants.PREF_VARIABLE_TEXT_FONT);
+		Font oldVariablesTreeFont = variablesTreeFont;
+		variablesTreeFont = fontDescriptor.createFont(tree.getDisplay());
+		tree.setFont(variablesTreeFont); // needed when themes are disabled
+		if (oldVariablesTreeFont != null) {
+			oldVariablesTreeFont.dispose();
+		}
+		IStylingEngine engine = PlatformUI.getWorkbench().getService(IStylingEngine.class);
+		if (engine != null) {
+			engine.setId(tree, CSS_VARIABLES_VIEWER_ID);
+		}
+	}
+
+	/**
+	 * Initializes the drag and/or drop adapters for this view.  Called from createViewer().
+	 *
+	 * @param viewer the viewer to add drag/drop support to.
+	 * @since 3.4
+	 */
+	protected void initDragAndDrop(TreeModelViewer viewer) {
+		// Drag only
+		viewer.addDragSupport(DND.DROP_COPY, new Transfer[] {LocalSelectionTransfer.getTransfer()}, new SelectionDragAdapter(viewer));
+	}
 
 	@Override
 	public void init(IViewSite site, IMemento memento) throws PartInitException {
 		super.init(site, memento);
 		PREF_STATE_MEMENTO = PREF_STATE_MEMENTO + site.getId();
-        IPreferenceStore store = DebugUIPlugin.getDefault().getPreferenceStore();
-        String string = store.getString(PREF_STATE_MEMENTO);
-        if(string.length() > 0) {
-			try (ByteArrayInputStream bin = new ByteArrayInputStream(string.getBytes()); InputStreamReader reader = new InputStreamReader(bin);) {
-        		XMLMemento stateMemento = XMLMemento.createReadRoot(reader);
-        		setMemento(stateMemento);
-        	} catch (WorkbenchException e) {
+		IPreferenceStore store = DebugUIPlugin.getDefault().getPreferenceStore();
+		String string = store.getString(PREF_STATE_MEMENTO);
+		if(string.length() > 0) {
+			try (ByteArrayInputStream bin = new ByteArrayInputStream(string.getBytes()); InputStreamReader reader = new InputStreamReader(bin)) {
+				XMLMemento stateMemento = XMLMemento.createReadRoot(reader);
+				setMemento(stateMemento);
+			} catch (WorkbenchException e) {
 			} catch (IOException e1) {
 			}
-        }
-        IMemento mem = getMemento();
-        // check the weights to makes sure they are valid -- bug 154025
-        setLastSashWeights(DEFAULT_SASH_WEIGHTS);
+		}
+		IMemento mem = getMemento();
+		// check the weights to makes sure they are valid -- bug 154025
+		setLastSashWeights(DEFAULT_SASH_WEIGHTS);
 		if (mem != null) {
 			int[] weights = getWeights(mem);
 			if (weights != null) {
@@ -561,7 +582,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 			}
 		}
 		site.getWorkbenchWindow().addPerspectiveListener(this);
-    }
+	}
 
 	/**
 	 * Returns sash weights stored in the given memento or <code>null</code> if none.
@@ -576,7 +597,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 			sw = memento.getInteger(SASH_DETAILS_PART);
 			if(sw != null) {
 				int details = sw.intValue();
-				if(view > -1 & details > -1) {
+				if(view > -1 && details > -1) {
 					return new int[] {view, details};
 				}
 			}
@@ -584,11 +605,11 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		return null;
 	}
 
-    @Override
+	@Override
 	public void partDeactivated(IWorkbenchPart part) {
 		String id = part.getSite().getId();
 		if (id.equals(getSite().getId())) {
-			try (ByteArrayOutputStream bout = new ByteArrayOutputStream(); OutputStreamWriter writer = new OutputStreamWriter(bout);) {
+			try (ByteArrayOutputStream bout = new ByteArrayOutputStream(); OutputStreamWriter writer = new OutputStreamWriter(bout)) {
 				XMLMemento memento = XMLMemento.createWriteRoot("VariablesViewMemento"); //$NON-NLS-1$
 				saveViewerState(memento);
 				memento.save(writer);
@@ -608,7 +629,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	 */
 	public void saveViewerState(IMemento memento) {
 		if (fSashForm != null && !fSashForm.isDisposed()) {
-	        int[] weights = fSashForm.getWeights();
+			int[] weights = fSashForm.getWeights();
 			memento.putInteger(SASH_VIEW_PART, weights[0]);
 			memento.putInteger(SASH_DETAILS_PART, weights[1]);
 		}
@@ -632,7 +653,6 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		int style = getViewerStyle();
 		fPresentationContext = new DebugModelPresentationContext(getPresentationContextId(), this, fModelPresentation);
 		final TreeModelViewer variablesViewer = new TreeModelViewer(parent, style, fPresentationContext);
-
 		variablesViewer.getControl().addFocusListener(new FocusAdapter() {
 			@Override
 			public void focusGained(FocusEvent e) {
@@ -643,23 +663,20 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 
 			@Override
 			public void focusLost(FocusEvent e){
-			    // Do not reset the selection provider with the provider proxy.
-			    // This should allow toolbar actions to remain active when the view
-			    // is de-activated but still visible.
-			    // Bug 316850.
+				// Do not reset the selection provider with the provider proxy.
+				// This should allow toolbar actions to remain active when the view
+				// is de-activated but still visible.
+				// Bug 316850.
 				clearGlobalActions();
 				getViewSite().getActionBars().updateActionBars();
 			}
 		});
 		variablesViewer.getPresentationContext().addPropertyChangeListener(
-				new IPropertyChangeListener() {
-					@Override
-					public void propertyChange(PropertyChangeEvent event) {
-						if (IPresentationContext.PROPERTY_COLUMNS.equals(event.getProperty())) {
-							IAction action = getAction("ShowTypeNames"); //$NON-NLS-1$
-							if (action != null) {
-								action.setEnabled(event.getNewValue() == null);
-							}
+				event -> {
+					if (IPresentationContext.PROPERTY_COLUMNS.equals(event.getProperty())) {
+						IAction action = getAction("ShowTypeNames"); //$NON-NLS-1$
+						if (action != null) {
+							action.setEnabled(event.getNewValue() == null);
 						}
 					}
 				});
@@ -717,7 +734,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	 * @since 3.7
 	 */
 	protected ISelection getDebugContext() {
-	    IViewSite site = (IViewSite)getSite();
+		IViewSite site = (IViewSite)getSite();
 		IDebugContextService contextService = DebugUITools.getDebugContextManager().getContextService(site.getWorkbenchWindow());
 		return contextService.getActiveContext(site.getId(), site.getSecondaryId());
 	}
@@ -1017,23 +1034,20 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		fConfigureColumnsAction = new ConfigureColumnsAction(viewer);
 		setAction("ToggleColmns", new ToggleShowColumnsAction(viewer)); //$NON-NLS-1$
 
-		layoutSubMenu.addMenuListener(new IMenuListener() {
-			@Override
-			public void menuAboutToShow(IMenuManager manager) {
-				layoutSubMenu.add(fToggleDetailPaneActions[0]);
-				layoutSubMenu.add(fToggleDetailPaneActions[1]);
-				layoutSubMenu.add(fToggleDetailPaneActions[2]);
-				layoutSubMenu.add(fToggleDetailPaneActions[3]);
-				layoutSubMenu.add(new Separator());
-				IAction action = getAction("ToggleColmns"); //$NON-NLS-1$
-				((IUpdate)action).update();
-				if (action.isEnabled()) {
-					layoutSubMenu.add(action);
-				}
-				fConfigureColumnsAction.update();
-				if (fConfigureColumnsAction.isEnabled()) {
-					layoutSubMenu.add(fConfigureColumnsAction);
-				}
+		layoutSubMenu.addMenuListener(manager -> {
+			layoutSubMenu.add(fToggleDetailPaneActions[0]);
+			layoutSubMenu.add(fToggleDetailPaneActions[1]);
+			layoutSubMenu.add(fToggleDetailPaneActions[2]);
+			layoutSubMenu.add(fToggleDetailPaneActions[3]);
+			layoutSubMenu.add(new Separator());
+			IAction action = getAction("ToggleColmns"); //$NON-NLS-1$
+			((IUpdate)action).update();
+			if (action.isEnabled()) {
+				layoutSubMenu.add(action);
+			}
+			fConfigureColumnsAction.update();
+			if (fConfigureColumnsAction.isEnabled()) {
+				layoutSubMenu.add(fConfigureColumnsAction);
 			}
 		});
 	}
@@ -1062,7 +1076,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		tbm.add(getAction(COLLAPSE_ALL));
 	}
 
-   /**
+	/**
 	* Adds items to the tree viewer's context menu including any extension defined
 	* actions.
 	*
@@ -1075,7 +1089,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		menu.add(getAction(FIND_ACTION));
 		ChangeVariableValueAction changeValueAction = (ChangeVariableValueAction)getAction("ChangeVariableValue"); //$NON-NLS-1$
 		if (changeValueAction.isApplicable()) {
-		    menu.add(changeValueAction);
+			menu.add(changeValueAction);
 		}
 		menu.add(new Separator());
 		IAction action = new AvailableLogicalStructuresAction(this);
@@ -1091,31 +1105,28 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		menu.add(new Separator(IWorkbenchActionConstants.MB_ADDITIONS));
 	}
 
-   /**
+	/**
 	 * Lazily instantiate and return a selection listener that populates the detail pane,
 	 * but only if the detail is currently visible.
 	 *
 	 * @return Created selection listener
 	 */
-    protected ISelectionChangedListener getTreeSelectionChangedListener() {
-        if (fTreeSelectionChangedListener == null) {
-            fTreeSelectionChangedListener = new ISelectionChangedListener() {
-                @Override
-				public void selectionChanged(final SelectionChangedEvent event) {
-                    if (event.getSelectionProvider().equals(getViewer())) {
-                        clearStatusLine();
-                        // if the detail pane is not visible, don't waste time retrieving details
-                        if (fSashForm.getMaximizedControl() == getViewer().getControl()) {
-                            return;
-                        }
-                        refreshDetailPaneContents();
-                        treeSelectionChanged(event);
-                    }
-                }
-            };
-        }
-        return fTreeSelectionChangedListener;
-    }
+	protected ISelectionChangedListener getTreeSelectionChangedListener() {
+		if (fTreeSelectionChangedListener == null) {
+			fTreeSelectionChangedListener = event -> {
+				if (event.getSelectionProvider().equals(getViewer())) {
+					clearStatusLine();
+					// if the detail pane is not visible, don't waste time retrieving details
+					if (fSashForm.getMaximizedControl() == getViewer().getControl()) {
+						return;
+					}
+					refreshDetailPaneContents();
+					treeSelectionChanged(event);
+				}
+			};
+		}
+		return fTreeSelectionChangedListener;
+	}
 
 	/**
 	 * Selection in the variable tree changed. Perform any updates.
@@ -1173,12 +1184,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	@Override
 	public void paneChanged(String newPaneID) {
 		if (fDetailPaneActivatedListener == null){
-			fDetailPaneActivatedListener = 	new Listener() {
-				@Override
-				public void handleEvent(Event event) {
-					fTreeHasFocus = false;
-				}
-			};
+			fDetailPaneActivatedListener = 	event -> fTreeHasFocus = false;
 		}
 		fDetailPane.getCurrentControl().addListener(SWT.Activate, fDetailPaneActivatedListener);
 	}
@@ -1322,7 +1328,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	 * @param flag If true, turns the logical structures on.
 	 */
 	public void setShowLogicalStructure(boolean flag) {
-	    getPresentationContext().setProperty(PRESENTATION_SHOW_LOGICAL_STRUCTURES, Boolean.valueOf(flag));
+		getPresentationContext().setProperty(PRESENTATION_SHOW_LOGICAL_STRUCTURES, Boolean.valueOf(flag));
 	}
 
 	/**
@@ -1336,7 +1342,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 
 	@Override
 	protected void becomesHidden() {
-        fInputService.resolveViewerInput(ViewerInputService.NULL_INPUT);
+		fInputService.resolveViewerInput(ViewerInputService.NULL_INPUT);
 		super.becomesHidden();
 	}
 
@@ -1381,7 +1387,7 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		delta.accept(fVisitor);
 
 		updateAction(FIND_ACTION);
-        updateAction(COLLAPSE_ALL);
+		updateAction(COLLAPSE_ALL);
 	}
 
 	@Override
@@ -1394,8 +1400,8 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 				showViewer();
 			}
 			if (TreePath.EMPTY.equals(update.getElementPath())) {
-			    updateAction(FIND_ACTION);
-			    updateAction(COLLAPSE_ALL);
+				updateAction(FIND_ACTION);
+				updateAction(COLLAPSE_ALL);
 			}
 		}
 	}
@@ -1407,11 +1413,11 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 	@Override
 	public synchronized void viewerUpdatesBegin() {
 		fTriggerDetailsJob.cancel();
-        IWorkbenchSiteProgressService progressService =
-            getSite().getAdapter(IWorkbenchSiteProgressService.class);
-        if (progressService != null) {
-            progressService.incrementBusy();
-        }
+		IWorkbenchSiteProgressService progressService =
+			getSite().getAdapter(IWorkbenchSiteProgressService.class);
+		if (progressService != null) {
+			progressService.incrementBusy();
+		}
 	}
 
 	@Override
@@ -1419,11 +1425,11 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 		if (fVisitor.isTriggerDetails()) {
 			fTriggerDetailsJob.schedule();
 		}
-        IWorkbenchSiteProgressService progressService =
-            getSite().getAdapter(IWorkbenchSiteProgressService.class);
-        if (progressService != null) {
-            progressService.decrementBusy();
-        }
+		IWorkbenchSiteProgressService progressService =
+			getSite().getAdapter(IWorkbenchSiteProgressService.class);
+		if (progressService != null) {
+			progressService.decrementBusy();
+		}
 	}
 
 	@Override
@@ -1440,9 +1446,9 @@ public class VariablesView extends AbstractDebugView implements IDebugContextLis
 
 	protected ToggleDetailPaneAction getToggleDetailPaneAction(String orientation)
 	{
-		for (int i=0; i<fToggleDetailPaneActions.length; i++) {
-			if (fToggleDetailPaneActions[i].getOrientation().equals(orientation)) {
-				return fToggleDetailPaneActions[i];
+		for (ToggleDetailPaneAction action : fToggleDetailPaneActions) {
+			if (action.getOrientation().equals(orientation)) {
+				return action;
 			}
 		}
 
