@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2000, 2018 IBM Corporation and others.
+ * Copyright (c) 2000, 2019 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -16,7 +16,7 @@ package org.eclipse.ui.console;
 
 import java.io.IOException;
 import java.io.InputStream;
-import java.io.UnsupportedEncodingException;
+import java.nio.charset.Charset;
 
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Color;
@@ -53,11 +53,6 @@ public class IOConsoleInputStream extends InputStream {
 	 */
 	private int size = 0;
 
-	/**
-	 * Flag to indicate that EOF has been sent already.
-	 */
-	private boolean eofSent = false;
-
 	/**
 	 * Flag to indicate that the stream has been closed.
 	 */
@@ -88,14 +83,14 @@ public class IOConsoleInputStream extends InputStream {
 		this.console = console;
 	}
 
-	/*
-	 *  (non-Javadoc)
-	 * @see java.io.InputStream#read(byte[], int, int)
-	 */
 	@Override
 	public synchronized int read(byte[] b, int off, int len) throws IOException {
+		if (len == 0) {
+			return 0; // behavior as specified in InputStream#read(byte[], int, int)
+		}
+
 		waitForData();
-		if (available() == -1) {
+		if (available() <= 0) {
 			return -1;
 		}
 
@@ -114,23 +109,15 @@ public class IOConsoleInputStream extends InputStream {
 		return toCopy;
 	}
 
-	/*
-	 *  (non-Javadoc)
-	 * @see java.io.InputStream#read(byte[])
-	 */
 	@Override
 	public int read(byte[] b) throws IOException {
 		return read(b, 0, b.length);
 	}
 
-	/*
-	 *  (non-Javadoc)
-	 * @see java.io.InputStream#read()
-	 */
 	@Override
 	public synchronized int read() throws IOException {
 		waitForData();
-		if (available() == -1) {
+		if (available() <= 0) {
 			return -1;
 		}
 
@@ -163,14 +150,10 @@ public class IOConsoleInputStream extends InputStream {
 	 * @param text the text to append to the buffer.
 	 */
 	public synchronized void appendData(String text) {
-		String encoding = console.getEncoding();
+		Charset charset = console.getCharset();
 		byte[] newData;
-		if (encoding!=null) {
-			try {
-				newData = text.getBytes(encoding);
-			} catch (UnsupportedEncodingException e) {
-				newData = text.getBytes();
-			}
+		if (charset != null) {
+			newData = text.getBytes(charset);
 		} else {
 			newData = text.getBytes();
 		}
@@ -262,25 +245,11 @@ public class IOConsoleInputStream extends InputStream {
 		return color;
 	}
 
-	/* (non-Javadoc)
-	 * @see java.io.InputStream#available()
-	 */
 	@Override
 	public int available() throws IOException {
-		if (closed && eofSent) {
-			throw new IOException("Input Stream Closed"); //$NON-NLS-1$
-		} else if (size == 0) {
-			if (!eofSent) {
-				eofSent = true;
-				return -1;
-			}
-		}
 		return size;
 	}
 
-	/* (non-Javadoc)
-	 * @see java.io.InputStream#close()
-	 */
 	@Override
 	public synchronized void close() throws IOException {
 		if(closed) {
