@@ -36,8 +36,6 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionAdapter;
 import org.eclipse.swt.events.SelectionEvent;
-import org.eclipse.swt.events.TraverseEvent;
-import org.eclipse.swt.events.TraverseListener;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -161,7 +159,7 @@ public abstract class ExternalToolsMainTab extends AbstractLaunchConfigurationTa
 		Composite buttonComposite = new Composite(group, SWT.NONE);
 		layout = new GridLayout();
 		layout.marginHeight = 0;
-        layout.marginWidth = 0;
+		layout.marginWidth = 0;
 		layout.numColumns = 3;
 		gridData = new GridData(GridData.HORIZONTAL_ALIGN_END);
 		buttonComposite.setLayout(layout);
@@ -213,8 +211,8 @@ public abstract class ExternalToolsMainTab extends AbstractLaunchConfigurationTa
 
 		Composite buttonComposite = new Composite(group, SWT.NONE);
 		layout = new GridLayout();
-        layout.marginWidth = 0;
-        layout.marginHeight = 0;
+		layout.marginWidth = 0;
+		layout.marginHeight = 0;
 		layout.numColumns = 3;
 		gridData = new GridData(GridData.HORIZONTAL_ALIGN_END);
 		buttonComposite.setLayout(layout);
@@ -257,15 +255,12 @@ public abstract class ExternalToolsMainTab extends AbstractLaunchConfigurationTa
 		GridData gridData = new GridData(GridData.FILL_BOTH);
 		group.setLayout(layout);
 		group.setLayoutData(gridData);
-        group.setFont(parent.getFont());
+		group.setFont(parent.getFont());
 
 		argumentField = new Text(group, SWT.MULTI | SWT.WRAP | SWT.BORDER | SWT.V_SCROLL);
-		argumentField.addTraverseListener(new TraverseListener() {
-			@Override
-			public void keyTraversed(TraverseEvent event) {
-				if (event.detail == SWT.TRAVERSE_RETURN && (event.stateMask & SWT.MODIFIER_MASK) != 0) {
-					event.doit= true;
-				}
+		argumentField.addTraverseListener(event -> {
+			if (event.detail == SWT.TRAVERSE_RETURN && (event.stateMask & SWT.MODIFIER_MASK) != 0) {
+				event.doit= true;
 			}
 		});
 
@@ -279,8 +274,8 @@ public abstract class ExternalToolsMainTab extends AbstractLaunchConfigurationTa
 		Composite composite = new Composite(group, SWT.NONE);
 		layout = new GridLayout();
 		layout.numColumns= 1;
-        layout.marginHeight= 0;
-        layout.marginWidth= 0;
+		layout.marginHeight= 0;
+		layout.marginWidth= 0;
 		gridData = new GridData(GridData.HORIZONTAL_ALIGN_END);
 		composite.setLayout(layout);
 		composite.setLayoutData(gridData);
@@ -624,9 +619,9 @@ public abstract class ExternalToolsMainTab extends AbstractLaunchConfigurationTa
 	public void addControlAccessibleListener(Control control, String controlName) {
 		//strip mnemonic (&)
 		String[] strs = controlName.split("&"); //$NON-NLS-1$
-		StringBuffer stripped = new StringBuffer();
-		for (int i = 0; i < strs.length; i++) {
-			stripped.append(strs[i]);
+		StringBuilder stripped = new StringBuilder();
+		for (String str : strs) {
+			stripped.append(str);
 		}
 		control.getAccessible().addAccessibleListener(new ControlAccessibleListener(stripped.toString()));
 	}
